import "react-responsive-carousel/lib/styles/carousel.min.css"; // requires a loader

import React from "react";

import { Carousel } from "react-responsive-carousel";

import Head from "@docusaurus/Head";
import Link from "@docusaurus/Link";
import useBaseUrl from "@docusaurus/useBaseUrl";
import useDocusaurusContext from "@docusaurus/useDocusaurusContext";
import Layout from "@theme/Layout";
import Heading from '@theme/Heading';

import { SocialCard, SocialCardProps } from "../components/homepage/SocialCard";

const features = [
	{
		title: "Основа мережі — Спілкування",
		imageUrl: "img/homepage/messages.svg",
		description: (
			<>
				Мережу в першу чергу, створюють люди, а не технології. Спілкування
				дозволяє нам зберігати зв'язок з друзями та родиною, а також будувати
				новий, цікавий і вільний світ.
			</>
		),
	},
	{
		title: "Захист",
		imageUrl: "img/homepage/encryption.svg",
		description: (
			<>
				Ми намагаємося захистити вашу приватність, використовуючи шифрування де
				це можливо та необхідно. Ви можете використовувати власні ключі
				шифрування, щоб забезпечити максимальний рівень захисту. Ми також
				відкриті для аудиту та вдосконалення наших методів шифрування та
				захисту.
			</>
		),
	},
	{
		title: "Незалежність",
		imageUrl: "img/homepage/platforms.svg",
		description: (
			<>
				Свобода спілкування не повинна бути обмежена. Ми намагаємося
				підтримувати якомога більше платформ, щоб ви могли спілкуватися з
				друзями та родиною, незалежно від того, який пристрій ви використовуєте.
			</>
		),
	},
	{
		title: "Open Source",
		imageUrl: "img/homepage/opensource.svg",
		description: (
			<>
				Мережа побудована на основі відкритих проектів, що дозволяє вам приймати
				участь в розвитку та вдосконаленні мережі.
			</>
		),
	},
];

const SocialCards: SocialCardProps[] = [
	{
		color: "bg-[#3875EA]",
		link: "https://irc.dead.guru",
		children: (
			<img alt="irc" className="m-auto h-10" src="/img/services/irc.svg" />
		),
	},
	{
		color: "bg-[#FFFFFF]",
		link: "https://matrix.to/#/#adhd_lab:hypogea.org",
		children: (
			<img
				alt="matrix"
				className="m-auto h-14"
				src="/img/services/Matrix_logo.svg"
			/>
		),
	},
	{
		color: "bg-[#95c0d9]",
		link: "https://xmpp.dead.guru:5281/",
		children: (
			<img
				alt="xmpp"
				className="m-auto h-14"
				src="/img/services/XMPP_logo.svg"
			/>
		),
	},
	{
		color: "bg-[#f05539]",
		link: "https://git.dead.guru/",
		children: (
			<img alt="git" className="m-auto h-14" src="/img/services/git_logo.svg" />
		),
	},
	{
		color: "bg-[#9e9b9a]",
		link: "https://mine.dead.guru",
		children: (
			<img
				alt="minecraft"
				className="m-auto h-16"
				src="/img/services/minecraft_logo.svg"
			/>
		),
	},
	{
		color: "bg-[#39322b]",
		link: "https://bookhouse.hypogea.org/",
		children: (
			<img
				alt="Calibre"
				className="m-auto h-12"
				src="/img/services/Calibre_logo.png"
			/>
		),
	},
	{
		color: "bg-[#6366f1]",
		link: "https://pi.dead.guru",
		children: (
			<img
				alt="reddit"
				className="m-auto h-20"
				src="/img/services/Pixelfed_logo.svg"
			/>
		),
	},
];

function Home() {
	const context = useDocusaurusContext();
	const { siteConfig } = context;
	return (
		<Layout>
			<Head>
				<meta property="og:title" content="Dead Network" />
				<meta
					property="og:image"
					content="https://network.dead.guru/img/social-preview-1200x630.png"
				/>
				<meta
					property="og:description"
					content="Надаємо різноманітні сервіси-платформи, які дають змогу окремим особам і спільнотам спілкуватися, ділитися та розвиватися разом."
				/>
				<meta property="og:url" content="https://network.dead.guru/" />
				<meta name="twitter:card" content="summary_large_image" />
			</Head>
			<header style={{ textAlign: "center" }} className="hero bg-transparent">
				<div className="container">
					<img src="/img/banner.gif" className="mx-auto" alt="" />
					<p className="hero__subtitle">{siteConfig.tagline}</p>
					<div className="indexCtas">
						<Link className="button button--lg text-gray-900 bg-gradient-to-r from-teal-200 to-lime-200 hover:bg-gradient-to-l hover:from-teal-200 hover:to-lime-200 focus:ring-4 focus:outline-none focus:ring-lime-200 dark:focus:ring-teal-700 font-medium rounded-lg text-sm px-5 py-2.5 text-center mr-2 mb-2" to="/docs/introduction">
							Дізнатися більше
						</Link>
					</div>
				</div>
			</header>
			<main className="flex flex-col gap-4">
				<div className="bg-primaryDark mx-auto flex w-full lg:w-auto flex-col gap-4 p-4 shadow-inner">
					<h3 className="text-xl font-bold">Приєднуйтесь до нас.</h3>
					<div className="flex w-full overflow-x-auto">
						{SocialCards.map((card) => (
							<SocialCard key={card.link} color={card.color} link={card.link}>
								{card.children}
							</SocialCard>
						))}
					</div>
				</div>
				<section className="">
					<div className="py-8 px-4 mx-auto max-w-screen-xl sm:py-16 lg:px-6">
						<h2 className="mb-8 text-4xl tracking-tight font-extrabold text-gray-900 dark:text-white">Основні положення</h2>
						<div className="grid pt-8 text-left border-t border-gray-200 md:gap-16 dark:border-gray-700 md:grid-cols-2">
							<div>
								<div className="mb-10">
									<h3 className="flex items-center mb-4 text-lg font-medium text-gray-900 dark:text-white">
										<svg className="flex-shrink-0 mr-2 w-5 h-5 text-gray-500 dark:text-gray-400" fill="currentColor" viewBox="0 0 20 20" xmlns="http://www.w3.org/2000/svg"><path fill-rule="evenodd" d="M18 10a8 8 0 11-16 0 8 8 0 0116 0zm-8-3a1 1 0 00-.867.5 1 1 0 11-1.731-1A3 3 0 0113 8a3.001 3.001 0 01-2 2.83V11a1 1 0 11-2 0v-1a1 1 0 011-1 1 1 0 100-2zm0 8a1 1 0 100-2 1 1 0 000 2z" clip-rule="evenodd"></path></svg>
										Основа мережі — Спілкування
									</h3>
									<p className="text-gray-500 dark:text-gray-400">Мережу в першу чергу, створюють люди, а не технології. Спілкування
				дозволяє нам зберігати зв'язок з друзями та родиною, а також будувати
				новий, цікавий і вільний світ.</p>
								</div>
								<div className="mb-10">                        
									<h3 className="flex items-center mb-4 text-lg font-medium text-gray-900 dark:text-white">
										<svg className="flex-shrink-0 mr-2 w-5 h-5 text-gray-500 dark:text-gray-400" fill="currentColor" viewBox="0 0 20 20" xmlns="http://www.w3.org/2000/svg"><path fill-rule="evenodd" d="M18 10a8 8 0 11-16 0 8 8 0 0116 0zm-8-3a1 1 0 00-.867.5 1 1 0 11-1.731-1A3 3 0 0113 8a3.001 3.001 0 01-2 2.83V11a1 1 0 11-2 0v-1a1 1 0 011-1 1 1 0 100-2zm0 8a1 1 0 100-2 1 1 0 000 2z" clip-rule="evenodd"></path></svg>
										Захист
									</h3>
									<p className="text-gray-500 dark:text-gray-400">Ми намагаємося захистити вашу приватність, використовуючи шифрування де
				це можливо та необхідно. Ви можете використовувати власні ключі
				шифрування, щоб забезпечити максимальний рівень захисту. Ми також
				відкриті для аудиту та вдосконалення наших методів шифрування та
				захисту.</p>
								</div>
								
							</div>
							<div>
							<div className="mb-10">
									<h3 className="flex items-center mb-4 text-lg font-medium text-gray-900 dark:text-white">
										<svg className="flex-shrink-0 mr-2 w-5 h-5 text-gray-500 dark:text-gray-400" fill="currentColor" viewBox="0 0 20 20" xmlns="http://www.w3.org/2000/svg"><path fill-rule="evenodd" d="M18 10a8 8 0 11-16 0 8 8 0 0116 0zm-8-3a1 1 0 00-.867.5 1 1 0 11-1.731-1A3 3 0 0113 8a3.001 3.001 0 01-2 2.83V11a1 1 0 11-2 0v-1a1 1 0 011-1 1 1 0 100-2zm0 8a1 1 0 100-2 1 1 0 000 2z" clip-rule="evenodd"></path></svg>
										Незалежність
									</h3>
									<p className="text-gray-500 dark:text-gray-400">Свобода спілкування не повинна бути обмежена. Ми намагаємося
				підтримувати якомога більше платформ, щоб ви могли спілкуватися з
				друзями та родиною, незалежно від того, який пристрій ви використовуєте.</p>
								</div>
								<div className="mb-10">
									<h3 className="flex items-center mb-4 text-lg font-medium text-gray-900 dark:text-white">
										<svg className="flex-shrink-0 mr-2 w-5 h-5 text-gray-500 dark:text-gray-400" fill="currentColor" viewBox="0 0 20 20" xmlns="http://www.w3.org/2000/svg"><path fill-rule="evenodd" d="M18 10a8 8 0 11-16 0 8 8 0 0116 0zm-8-3a1 1 0 00-.867.5 1 1 0 11-1.731-1A3 3 0 0113 8a3.001 3.001 0 01-2 2.83V11a1 1 0 11-2 0v-1a1 1 0 011-1 1 1 0 100-2zm0 8a1 1 0 100-2 1 1 0 000 2z" clip-rule="evenodd"></path></svg>
										Open Source
									</h3>
									<p className="text-gray-500 dark:text-gray-400">Мережа побудована на основі відкритих проектів, що дозволяє вам приймати
				участь в розвитку та вдосконаленні мережі. Ми намагаємося публікувати всі наші розробки на загал одразу.</p>
									<p className="text-gray-500 dark:text-gray-400">Знайти наші відкриті проекти ви можете <a href="#" className="font-medium underline text-primary-600 dark:text-primary-500 hover:no-underline">на GitHub</a>, або на DeadTea.</p>
								</div>
							</div>
						</div>
					</div>
				</section>
			</main>
		</Layout>
	);
}

export default Home;
